@@ -112,7 +112,8 @@ void linecopylen(
 #define ERROR_BUFFER_LEN 256
 
 /* C specific */
-#ifndef __cplusplus
+/* VC needs these in C++ mode too (do other compilers?) */
+#if !defined(__cplusplus) || defined(UPNP_USE_MSVCPP)
 	#ifdef WIN32
 		#ifndef S_ISREG
 			#define S_ISREG(m) (((m) & S_IFMT) == S_IFREG)
@@ -130,7 +131,7 @@ void linecopylen(
 		#define max(a, b)   (((a)>(b))? (a):(b))
 		#define min(a, b)   (((a)<(b))? (a):(b))
 	#endif /* WIN32 */
-#endif /* __cplusplus */
+#endif /* !defined(__cplusplus) || defined(UPNP_USE_MSVCPP) */
 
 #endif /* UTIL_H */
 
